"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.executeBundleHooks = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const ern_cauldron_api_1 = require("ern-cauldron-api");
const path_1 = __importDefault(require("path"));
const shelljs_1 = __importDefault(require("shelljs"));
const tmp_1 = __importDefault(require("tmp"));
async function executeBundleHooks(scriptPath, workingDirectory) {
    let pathToScript = scriptPath;
    if (pathToScript.startsWith('cauldron://')) {
        const localRepoPath = tmp_1.default.dirSync({ unsafeCleanup: true }).name;
        const cauldron = await (0, ern_cauldron_api_1.getActiveCauldron)({
            localRepoPath,
            throwIfNoActiveCauldron: false,
        });
        if (!cauldron) {
            throw new Error(`A Cauldron needs to be active to run ${pathToScript}`);
        }
        else if (!(await cauldron.hasFile({ cauldronFilePath: pathToScript }))) {
            throw new Error(`Cannot find ${pathToScript} in Cauldron`);
        }
        const scriptFile = await cauldron.getFile({
            cauldronFilePath: pathToScript,
        });
        const scriptFileName = path_1.default.basename(pathToScript.replace('cauldron://', ''));
        const tmpScriptDir = tmp_1.default.dirSync({ unsafeCleanup: true }).name;
        pathToScript = path_1.default.join(tmpScriptDir, scriptFileName);
        fs_extra_1.default.writeFileSync(pathToScript, scriptFile.toString());
        shelljs_1.default.chmod('+x', pathToScript);
    }
    const scriptResult = shelljs_1.default.exec(pathToScript, { cwd: workingDirectory });
    if (scriptResult.code !== 0) {
        throw new Error(`Script execution failed with code ${scriptResult.code}`);
    }
    return scriptResult.code;
}
exports.executeBundleHooks = executeBundleHooks;
//# sourceMappingURL=executeBundleHooks.js.map